# Changelog

## Unreleased
## Added
- Explicit telegram imprinting
## Fixed
- Dynamically import only what's needed in checks

## [4.0.1] - 2017-05-10
## Added
- Credentials extensions through entry points (for kibitzr-keyring).

## [4.0.0] - 2017-05-08
## Added
- `kibitzr init` - create sample configuration files
## Changed
- Changed kibitzr CLI commands structure (`kibitzr run` instead of `kibitzr`)

## [3.1.8] - 2017-05-08
## Fixed
- Unspecified period caused error (introduced in 3.1.4)

## [3.1.7] - 2017-05-06
## Fixed
- Gracefull shutdown on SIGTERM (as on SIGINT)

## [3.1.6] - 2017-05-05
## Fixed
- Jinja transform
## Added
- CHANGELOG to PyPI page

## [3.1.4] - 2017-05-04
## Changed
- human-readable period

## [3.1.3] - 2017-05-01
## Fixed
- Bash and Python transforms parameter (dis)order
- Skip Bash transform if input is empty
## Changed
- Requests fetcher uses caching

## [3.1.0] - 2017-05-01
## Added
- Jinja transform
## Removed
- cut and sort transforms (superseded by bash)

## [3.0.11] - 2017-04-30
## Added
- Browser form filling shorthand

## [3.0.10] - 2017-04-29
## Added
- Bash transform
## Fixed
- jq transform input encoding

## [3.0.9] - 2017-04-25
## Fixed
- Firefox fetcher: retry 3 times on stale element exception
- Persistent Firefox: Ignore all exceptions when closing

## [3.0.8] - 2017-04-24
## Added
- Transformer css-all selector which returns all elements instead of first
- Python transformer
## Changed
- Missing check name autopopulated from URL or autogenerated

## [3.0.7] - 2017-04-19
## Added
- Zapier notifier

## [3.0.6] - 2017-04-19
## Added
- Telegram notifier

## [3.0.3] - 2017-04-18
## Added
- Persistent firefox profile [undocumented]

## [3.0.2] - 2017-04-18
## Added
- Short form for SMTP notifier #11
## Fixed
- Weird BS4 misbehaviour in CSS selector

## [3.0.1] - 2017-04-07
## Fixed
- Exit if no checks defined
- Better credentials reloading

## [3.0.0] - 2017-04-04
## Changed
- Switched to selenium >3 and Firefox >48

## [2.7.4] - 2017-04-01
## Changed
- Closing FireFox tab after it was fetched to reduce idle CPU

## [2.7.3] - 2017-03-31
## Added
- Started CHANGELOG
- script.python fetcher
